==> kubernetes-model-core-5.3.0-sources.jar: io/fabric8/kubernetes/api/model/IntOrStringFluentImpl.java <==
package io.fabric8.kubernetes.api.model;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Integer;
import java.lang.StringBuffer;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

public class IntOrStringFluentImpl<A extends IntOrStringFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements IntOrStringFluent<A> {

    private Integer IntVal;
    private Integer Kind;
    private String StrVal;
    private Map<String,Object> additionalProperties;

    public IntOrStringFluentImpl() {
    }

    public IntOrStringFluentImpl(IntOrString instance) {
        this.withIntVal(instance.getIntVal()); 
        this.withKind(instance.getKind()); 
        this.withStrVal(instance.getStrVal()); 
        this.withAdditionalProperties(instance.getAdditionalProperties()); 
        this.withIntVal(instance.getIntVal());
        
        this.withKind(instance.getKind());
        
        this.withStrVal(instance.getStrVal());
    }

    public Integer getIntVal() {
        return this.IntVal;
    }

    public A withIntVal(Integer IntVal) {
        this.IntVal=IntVal; return (A) this;
    }

    public Boolean hasIntVal() {
        return this.IntVal != null;
    }

    public A withNewIntVal(int arg1) {
        return (A)withIntVal(new Integer(arg1));
    }

    public Integer getKind() {
        return this.Kind;
    }

    public A withKind(Integer Kind) {
        this.Kind=Kind; return (A) this;
    }

    public Boolean hasKind() {
        return this.Kind != null;
    }

    public A withNewKind(int arg1) {
        return (A)withKind(new Integer(arg1));
    }

    public String getStrVal() {
        return this.StrVal;
    }

    public A withStrVal(String StrVal) {
        this.StrVal=StrVal; return (A) this;
    }

    public Boolean hasStrVal() {
        return this.StrVal != null;
    }

    public A withNewStrVal(StringBuilder arg1) {
        return (A)withStrVal(new String(arg1));
    }

    public A withNewStrVal(int[] arg1,int arg2,int arg3) {
        return (A)withStrVal(new String(arg1, arg2, arg3));
    }

    public A withNewStrVal(char[] arg1) {
        return (A)withStrVal(new String(arg1));
    }

    public A withNewStrVal(StringBuffer arg1) {
        return (A)withStrVal(new String(arg1));
    }

    public A withNewStrVal(byte[] arg1,int arg2) {
        return (A)withStrVal(new String(arg1, arg2));
    }

    public A withNewStrVal(byte[] arg1) {
        return (A)withStrVal(new String(arg1));
    }

    public A withNewStrVal(char[] arg1,int arg2,int arg3) {
        return (A)withStrVal(new String(arg1, arg2, arg3));
    }

    public A withNewStrVal(byte[] arg1,int arg2,int arg3) {
        return (A)withStrVal(new String(arg1, arg2, arg3));
    }

    public A withNewStrVal(byte[] arg1,int arg2,int arg3,int arg4) {
        return (A)withStrVal(new String(arg1, arg2, arg3, arg4));
    }

    public A withNewStrVal(String arg1) {
        return (A)withStrVal(new String(arg1));
    }

    public A addToAdditionalProperties(String key,Object value) {
        if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap<String,Object>(); }
        if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
    }

    public A addToAdditionalProperties(Map<String,Object> map) {
        if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap<String,Object>(); }
        if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
    }

    public A removeFromAdditionalProperties(String key) {
        if(this.additionalProperties == null) { return (A) this; }
        if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
    }

    public A removeFromAdditionalProperties(Map<String,Object> map) {
        if(this.additionalProperties == null) { return (A) this; }
        if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
    }

    public Map<String,Object> getAdditionalProperties() {
        return this.additionalProperties;
    }

    public <K extends Object,V extends Object>A withAdditionalProperties(Map<String,Object> additionalProperties) {
        if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap<String,Object>(additionalProperties);} return (A) this;
    }

    public Boolean hasAdditionalProperties() {
        return this.additionalProperties != null;
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        IntOrStringFluentImpl that = (IntOrStringFluentImpl) o;
        if (IntVal != null ? !IntVal.equals(that.IntVal) :that.IntVal != null) return false;
        if (Kind != null ? !Kind.equals(that.Kind) :that.Kind != null) return false;
        if (StrVal != null ? !StrVal.equals(that.StrVal) :that.StrVal != null) return false;
        if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(IntVal,  Kind,  StrVal,  additionalProperties,  super.hashCode());
    }

}

==> kubernetes-model-core-5.3.1-sources.jar: io/fabric8/kubernetes/api/model/IntOrStringFluentImpl.java <==
package io.fabric8.kubernetes.api.model;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Integer;
import java.lang.StringBuffer;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

public class IntOrStringFluentImpl<A extends IntOrStringFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements IntOrStringFluent<A> {

    private Integer IntVal;
    private Integer Kind;
    private String StrVal;
    private java.util.Map<String,Object> additionalProperties;

    public IntOrStringFluentImpl() {
    }

    public IntOrStringFluentImpl(IntOrString instance) {
        this.withIntVal(instance.getIntVal()); 
        this.withKind(instance.getKind()); 
        this.withStrVal(instance.getStrVal()); 
        this.withAdditionalProperties(instance.getAdditionalProperties()); 
        this.withIntVal(instance.getIntVal());
        
        this.withKind(instance.getKind());
        
        this.withStrVal(instance.getStrVal());
    }

    public Integer getIntVal() {
        return this.IntVal;
    }

    public A withIntVal(Integer IntVal) {
        this.IntVal=IntVal; return (A) this;
    }

    public Boolean hasIntVal() {
        return this.IntVal != null;
    }

    public A withNewIntVal(int arg0) {
        return (A)withIntVal(new Integer(arg0));
    }

    public Integer getKind() {
        return this.Kind;
    }

    public A withKind(Integer Kind) {
        this.Kind=Kind; return (A) this;
    }

    public Boolean hasKind() {
        return this.Kind != null;
    }

    public A withNewKind(int arg0) {
        return (A)withKind(new Integer(arg0));
    }

    public String getStrVal() {
        return this.StrVal;
    }

    public A withStrVal(String StrVal) {
        this.StrVal=StrVal; return (A) this;
    }

    public Boolean hasStrVal() {
        return this.StrVal != null;
    }

    public A withNewStrVal(StringBuilder arg1) {
        return (A)withStrVal(new String(arg1));
    }

    public A withNewStrVal(int[] arg1,int arg2,int arg3) {
        return (A)withStrVal(new String(arg1, arg2, arg3));
    }

    public A withNewStrVal(char[] arg1) {
        return (A)withStrVal(new String(arg1));
    }

    public A withNewStrVal(StringBuffer arg1) {
        return (A)withStrVal(new String(arg1));
    }

    public A withNewStrVal(byte[] arg1,int arg2) {
        return (A)withStrVal(new String(arg1, arg2));
    }

    public A withNewStrVal(byte[] arg1) {
        return (A)withStrVal(new String(arg1));
    }

    public A withNewStrVal(char[] arg1,int arg2,int arg3) {
        return (A)withStrVal(new String(arg1, arg2, arg3));
    }

    public A withNewStrVal(byte[] arg1,int arg2,int arg3) {
        return (A)withStrVal(new String(arg1, arg2, arg3));
    }

    public A withNewStrVal(byte[] arg1,int arg2,int arg3,int arg4) {
        return (A)withStrVal(new String(arg1, arg2, arg3, arg4));
    }

    public A withNewStrVal(String arg1) {
        return (A)withStrVal(new String(arg1));
    }

    public A addToAdditionalProperties(String key,Object value) {
        if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap<String,Object>(); }
        if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
    }

    public A addToAdditionalProperties(java.util.Map<String,Object> map) {
        if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap<String,Object>(); }
        if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
    }

    public A removeFromAdditionalProperties(String key) {
        if(this.additionalProperties == null) { return (A) this; }
        if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
    }

    public A removeFromAdditionalProperties(java.util.Map<String,Object> map) {
        if(this.additionalProperties == null) { return (A) this; }
        if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
    }

    public java.util.Map<String,Object> getAdditionalProperties() {
        return this.additionalProperties;
    }

    public <K extends Object,V extends Object>A withAdditionalProperties(java.util.Map<String,Object> additionalProperties) {
        if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap<String,Object>(additionalProperties);} return (A) this;
    }

    public Boolean hasAdditionalProperties() {
        return this.additionalProperties != null;
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        IntOrStringFluentImpl that = (IntOrStringFluentImpl) o;
        if (IntVal != null ? !IntVal.equals(that.IntVal) :that.IntVal != null) return false;
        if (Kind != null ? !Kind.equals(that.Kind) :that.Kind != null) return false;
        if (StrVal != null ? !StrVal.equals(that.StrVal) :that.StrVal != null) return false;
        if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(IntVal,  Kind,  StrVal,  additionalProperties,  super.hashCode());
    }

}
